# -*- coding: utf-8 -*-
#$Id: testSetup.py 91 2006-03-09 16:24:08Z taka $
#############################################################################
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##############################################################################

#
# ATCTSmallSample Setup tests
#

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Testing import ZopeTestCase
from AccessControl import Unauthorized
from Products.ATCTSmallSample.tests.ATCTSSTestCase import ATCTSSTestCase
from Products.ATCTSmallSample.config import *

class TestInstallSmallContent(ATCTSSTestCase):

    def testSmallContentPortalType(self):
        """SmallContent in portal_types"""
        self.failUnless('SmallContent' in self.portal.portal_types.objectIds())

    def testSmallContentDynamicViewFTI(self):
        """SmallContent implemented by IDynamicViewTypeInformation"""
        small = getattr(self.folder, 'small')
        from Products.CMFDynamicViewFTI.interfaces import IDynamicViewTypeInformation
        info = self.portal.portal_types['SmallContent']
        self.failUnless(IDynamicViewTypeInformation.isImplementedBy(info))

    def testSmallContentPortalFactoryEnabled(self):
        """PortalFactory enabled on SmallContent"""
        from Products.CMFCore.utils import getToolByName
        factory = getToolByName(self.portal, 'portal_factory')
        types = factory.getFactoryTypes().keys()
        self.failUnless('SmallContent' in types)

    def testSmallContentSkin(self):
        """SmallContent skin path in portal_skins"""
        for selection in self.portal.portal_skins.getSkinSelections():
            path = self.portal.portal_skins.getSkinPath(selection)
            self.failUnless(PROJECTNAME in path)

    def testSmallContentPortalCSS(self):
        """smallcontent.css in portal_css"""
        cssreg = self.portal.portal_css
        stylesheet_ids = cssreg.getResourceIds()
        self.failUnless('smallcontent.css' in stylesheet_ids)


class TestUninstallSmallContent(ATCTSSTestCase):

    def testSmallContentSkin(self):
        """SmallContent skin path not in portal_skins"""
        self.uninstallProduct(PROJECTNAME)
        for selection in self.portal.portal_skins.getSkinSelections():
            path = self.portal.portal_skins.getSkinPath(selection)
            self.failUnless(PROJECTNAME not in path)

    def testSmallContentPortalCSS(self):
        """smallcontent.css not in portal_css"""
        self.uninstallProduct(PROJECTNAME)
        cssreg = self.portal.portal_css
        stylesheet_ids = cssreg.getResourceIds()
        self.failUnless('smallcontent.css' not in stylesheet_ids)


def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(TestInstallSmallContent))
    suite.addTest(makeSuite(TestUninstallSmallContent))
    return suite

if __name__ == '__main__':
    framework()
